@@ -1,16 +1,10 @@
-from datetime import datetime
-from concurrent.futures import ProcessPoolExecutor, as_completed
-from typing import NoReturn
+import logging
 from utils_api_pipefy.libs.pipefy import Pipefy
 from utils_api_pipefy.libs.log import log
-import logging
+from utils_api_pipefy.libs.excepts import exceptions
 
 log().loginit()
 
-class PipeExcept(Exception):
-    pass
-
-
 class Pipe(Pipefy):
     def __init__(self, token, host, pipe, nonphases):
         """
@@ -26,14 +20,13 @@ class Pipe(Pipefy):
                 - Nativas:
                     - from os import getenv
                     - from concurrent.futures import ProcessPoolExecutor, as_completed
-                    - from typing import NoReturn
                 - Externas:
                     - from dotenv import load_dotenv (Pode ser substituida de acordo com o Usuário)
                     - from api_pipefy.pipefy import Pipefy (Pode alterar de acordo com o Usuário)
                     
             `Variaveis aguardadas`:
                 - `TOKEN` : Bearer do Pipefy necessária para autorizar as chamadas da API.
-                - `HOST` : localhost necessário para determinar para onde será enviado a chamada da API, por padrão Pipefy é utlizado app.
+                - `HOST_PIPE` : localhost necessário para determinar para onde será enviado a chamada da API, por padrão Pipefy é utlizado app.
                 - `PIPE` : ID do Pipefy que deverá ser efetuado a query, mutation, etc...
                 - `NONPHASE` : Lista com ID das Fases que devem ser ignoradas.
         """
@@ -41,32 +34,18 @@ class Pipe(Pipefy):
         self.HOST = host
         self.PIPE = pipe
         self.NONPHASES = nonphases
-        self.phase_id = None
+        self.phases_id = None
         self.fields = None
         self.phases = None
         self.__get_field_and_phases()
         self.columns = self.get_coluns_id()
     
-    
-    def _timeit(func):
-        """
-        Decorator para cronometrar o tempo de exeção das funções.
-        """
-        def print_time(*args):
-            start = datetime.now()
-            print(f"{func.__name__} iniciado às {start}.")
-            func(*args)
-            end = datetime.now() - start
-            print(f"{func.__name__} finalizado às {datetime.now()}.\nTempo de execução (hh:mm:ss.ms) {end}")
-            
-        return print_time
        
-        
-    def __get_field_and_phases(self) -> NoReturn:
+    def __get_field_and_phases(self) -> None:
         """
         Função para pegar as fases, campos e id das fases do Pipefy
         
-        Chama a API consultaFields e trata o retorno:
+        Chama a API consulta_fields e trata o retorno:
             - Cria lista com id das fases.
             - Cria lista com id e nome das fases.
             - Cria lista com id e nome dos campos.
@@ -74,9 +53,12 @@ class Pipe(Pipefy):
         try:
             super().__init__(token=self.TOKEN, host=self.HOST)
             
-            campos_pipefy = self.consultaFields(pipe_id=self.PIPE)
+            campos_pipefy = self.consulta_fields(pipe_id=self.PIPE)
             
-            self.phases_id = [n.get("id") for n in campos_pipefy["phases"] if not n.get("id") in self.NONPHASES]
+            if self.NONPHASES:
+                self.phases_id = [n.get("id") for n in campos_pipefy["phases"] if not n.get("id") in eval(self.NONPHASES)]
+            else:
+                self.phases_id = [n.get("id") for n in campos_pipefy["phases"]]
             
             self.fields = {"fields":[{"id": d.get("id"), "nameField":d.get("label"), "editable":d.get("editable"), "uuid":d.get("uuid") , "required":d.get("required")} for n in campos_pipefy['phases'] for d in n['fields']] + [{"id": n.get("id"), "nameField": n.get("label"), "editable":n.get("editable"), "uuid":n.get("uuid"), "required":n.get("required")} for n in campos_pipefy['start_form_fields']]}
 
@@ -84,10 +66,10 @@ class Pipe(Pipefy):
             
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
     
     
-    def __extract_basics(self, card : dict) -> dict:
+    def __extract_basics(self, card : dict) -> list:
         """
         Para cada card é pego os dados dos campos abaixo.
         
@@ -101,7 +83,7 @@ class Pipe(Pipefy):
                     card.get("current_phase").get("name"),
                     card.get("labels")[0]["name"] if card.get("labels") else None,
                     card.get("due_date"),
-                    card.get("createdBy").get("name"),
+                    card.get("createdBy").get("name") if card.get("createdBy") != None else None,
                     card.get("assignees"),
                     card.get("finished_at"),
                     card.get("createdAt"),
@@ -110,10 +92,10 @@ class Pipe(Pipefy):
             return fields
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
         
 
-    def __extract_custom(self, card : dict) -> dict:
+    def __extract_custom(self, card : dict) -> list:
         """
         Para cada card, é pego os dados de acordo com os id passados na lista custom_schema
         
@@ -126,10 +108,10 @@ class Pipe(Pipefy):
             return [card_fields.get(n["id"],{}).get("value") for n in self.fields["fields"]]
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
         
 
-    def __extract_phases(self, card : dict) -> dict:
+    def __extract_phases(self, card : dict) -> list:
         """
         Para cada card é pego das inicial e final de cada fase no histórico de fases. (card["phases_history"])
         
@@ -147,11 +129,11 @@ class Pipe(Pipefy):
                     for info in informacoes:
                         fields.append(dados_phase[info])
                 else:
-                    [fields.append(None) for x in informacoes]
+                    [fields.append(None) for _ in informacoes]
             return fields
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
         
         
     def parse_phase_history(self, card : dict) -> dict:
@@ -169,7 +151,7 @@ class Pipe(Pipefy):
             return card
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
         
         
     def get_fields(self, card : dict) -> dict:
@@ -188,7 +170,7 @@ class Pipe(Pipefy):
             return card
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
             
             
     def parse_card(self, card : list) -> tuple:
@@ -211,7 +193,7 @@ class Pipe(Pipefy):
             return tuple(all_fields)
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
         
         
     def get_coluns_id(self) -> tuple:
@@ -247,7 +229,7 @@ class Pipe(Pipefy):
             return tuple(all_cols)
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
           
             
     def parse_data_cards(self, response_dados : list) -> list:
@@ -271,7 +253,7 @@ class Pipe(Pipefy):
             return dados_do_cards
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
     
     
     def get_data_phase(self, phase_id : str) -> dict:
@@ -318,38 +300,52 @@ class Pipe(Pipefy):
 
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
         
     
-    def update_fields_pipe(self, card_id : str, fields : dict) -> NoReturn:
+    def update_fields_pipe(self, card_id : str, fields : dict) -> None:
         """
-        Função de atualização de campos do Pipefy - API updateFieldsCard.
+        Função de atualização de campos do Pipefy - API update_fields_card.
         """
         try:
             
             response_fields = ', '.join(['{fieldId: "%s", value: "%s"}' % (key, fields[key]) for key in fields])
             
             super().__init__(token=self.TOKEN, host=self.HOST)
-            response = self.updateFieldsCard(nodeId=card_id, response_fields=response_fields)
+            response = self.update_fields_card(node_id=card_id, response_fields=response_fields)
             logging.info(f"Response: {response}")
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
     
     
-    def create_cards_pipe(self, fields : dict) -> NoReturn:
+    def create_cards_pipe(self, fields : dict) -> None:
         """
-        Função de atualização de campos do Pipefy - API updateFieldsCard.
+        Função de atualização de campos do Pipefy - API create_card.
         """
         try:
             
             super().__init__(token=self.TOKEN, host=self.HOST)
-            response = self.createCard(pipe_id=self.PIPE, fields_attributes=fields)
+            response = self.create_card(pipe_id=self.PIPE, fields_attributes=fields)
             logging.info(f"Response: {response}")
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
-          
+            raise exceptions(e)
+    
+    
+    def create_cards_pipe_phase(self, fields : dict) -> None:
+        """
+        Função de atualização de campos do Pipefy - API update_fields_card.
+        """
+        try:
+            
+            super().__init__(token=self.TOKEN, host=self.HOST)
+            response = self.create_card_phase( pipe_id=self.PIPE, fields_attributes=fields.get("fields"), due_date=fields.get("due_date"), phase_id=fields.get("phase_id"), label_ids=[fields.get("label_ids")] )
+            logging.info(f"Response: {response}")
+        except Exception as e:
+            logging.info(e)
+            raise exceptions(e)
+    
     
     def delete_cards(self, card_id : str) -> dict:
         """
@@ -357,26 +353,27 @@ class Pipe(Pipefy):
         """
         try:
             super().__init__(token=self.TOKEN, host=self.HOST)
-            response = self.deleteCard(id=card_id)
+            response = self.delete_card(id=card_id)
             logging.info(f"Exclusão de Cards - Card_ID: {card_id} - Response: {response}.")
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
 
 
-    def change_properties_fields(self, data : str ) -> NoReturn:
+    def change_properties_fields(self, data : str ) -> None:
         """
         Função que chama API do Pipefy que altera as propriedades de um campo.
         """
         try:
             super().__init__(token=self.TOKEN, host=self.HOST)
-            response = self.updatePropertiesFields(fields_attributes=data)
+            response = self.update_properties_fields(fields_attributes=data)
             logging.info(f"Response: {response}.")
         except Exception as e:
             logging.info(e)
-            raise PipeExcept(e)
+            raise exceptions(e)
         
-    def get_data_cards_filter(self, pipe_id):
+        
+    def get_data_cards_filter(self, pipe_id, filter_date : str = None) -> dict:
         """
         Função que pega todos os cards do Pipefy selecionado fazendo a paginação de acordo com a tag (pageInfo) retornada pelo Pipefy.
         Utiliza a função (parse_data_cards) para organizar os dados recebidos.
@@ -385,24 +382,41 @@ class Pipe(Pipefy):
         
         `Exemplo:` {"Status":True,"Data": [(....)(....)]}
         """
+        filter_date = filter_date or None
+        
         try:
-            response_phase = self.allCards(pipe_id=pipe_id)
+            response_phase = self.all_cards(pipe_id=pipe_id, filter_date=filter_date)
+            
             next_page_phase = response_phase['pageInfo']['hasNextPage']
+            
             response_edges_phase = response_phase.get('edges', {})
+            
             if response_edges_phase:
+                
                 response_dados = [n["node"] for n in response_edges_phase if response_edges_phase]
+                
                 dados_cards = self.parse_data_cards(response_dados=response_dados)
+                
                 while next_page_phase:
+                    
                     super().__init__(token=self.TOKEN, host=self.HOST)
+                    
                     after = response_phase['pageInfo']['endCursor'] if response_phase['pageInfo']['hasNextPage'] else None
-                    response_phase = self.allCards(pipe_id=pipe_id, after=after)
+                    
+                    response_phase = self.all_cards(pipe_id=pipe_id, after=after, filter_date=filter_date)
+                    
                     next_page_phase = response_phase['pageInfo']['hasNextPage']
+            
                     response_edges_phase = response_phase.get('edges', {})
+                    
                     response_dados = [n["node"] for n in response_edges_phase]
+                    
                     dados_cards += self.parse_data_cards(response_dados=response_dados)
+                
                 return {"Status":True,"Data": dados_cards}
             else:
-                return {"Status":False,"Data": None}
+                return {"Status":False,"Data": ""}
+
         except Exception as e:
-            logging.info(e)
-            raise PipeExcept(e)
\ No newline at end of file
+            self.logger.info(e)
+            raise exceptions(e)
\ No newline at end of file
